==> blesta-5.10.2.zip: blesta/plugins/order/language/ro_ro/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Email de recuperare (opțional)';
$lang['Signup.!error.email.blacklist'] = 'Comanda dvs. nu poate fi procesată în acest moment.';
$lang['Signup.index.signup_btn'] = 'Creați un cont';
$lang['Signup.index.continue_btn'] = 'Continuați la checkout';
$lang['Signup.index.login_btn'] = 'Autentificare';
$lang['Signup.index.field_receive_email_marketing'] = 'Doresc să primesc e-mailuri despre produse, servicii și oferte noi.';
$lang['Signup.index.field_confirmpassword'] = 'Confirmați parola';
$lang['Signup.index.field_newpassword'] = 'Parola';
$lang['Signup.index.field_password'] = 'Parola';
$lang['Signup.index.field_username'] = 'Nume utilizator';
$lang['Signup.index.field_action_signup'] = 'Creați un cont';
$lang['Signup.index.field_action_login'] = 'Autentificare';
$lang['Signup.index.field_action_continue'] = 'Continuați ca %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Specificați un nume de utilizator';
$lang['Signup.index.field_username_type_email'] = 'Utilizați e-mailul ca nume de utilizator';
$lang['Signup.index.field_email'] = 'Email';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Titlu';
$lang['Signup.index.field_country'] = 'Țara';
$lang['Signup.index.field_zip'] = 'Cod poștal';
$lang['Signup.index.field_state'] = 'Stat/Provincie';
$lang['Signup.index.field_city'] = 'Orașul';
$lang['Signup.index.field_address2'] = 'Adresa 2';
$lang['Signup.index.field_address1'] = 'Adresa 1';
$lang['Signup.index.field_company'] = 'Companie/Org.';
$lang['Signup.index.field_lastname'] = 'Numele de familie';
$lang['Signup.index.field_firstname'] = 'Primul nume';
$lang['Signup.index.field_taxid'] = 'Cod fiscal/VATIN';
$lang['Signup.!notice.email_verification'] = 'A fost trimis un mesaj pentru a verifica adresa dvs. de e-mail. Vă rugăm să finalizați verificarea cât mai curând posibil.';
$lang['Signup.!notice.force_email_usernames'] = 'Numele dvs. de utilizator va fi același cu adresa dvs. de e-mail.';
$lang['Signup.!error.not_client_owner'] = 'Trebuie să vă conectați ca proprietar al clientului pentru a continua.';
$lang['Signup.!error.captcha.invalid'] = 'Captcha introdus a fost invalid. Vă rugăm să încercați din nou.';

==> blesta-5.11.4.zip: blesta/plugins/order/language/ro_ro/signup.php <==
<?php
/**
 * Signup
 *
 * @package blesta
 * @subpackage blesta.language.ro_ro
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Signup.index.field_recovery_email'] = 'Email de recuperare (opțional)';
$lang['Signup.!error.email.blacklist'] = 'Comanda dvs. nu poate fi procesată în acest moment.';
$lang['Signup.index.signup_btn'] = 'Creați un cont';
$lang['Signup.index.continue_btn'] = 'Continuați la checkout';
$lang['Signup.index.login_btn'] = 'Autentificare';
$lang['Signup.index.field_receive_email_marketing'] = 'Doresc să primesc e-mailuri despre produse, servicii și oferte noi.';
$lang['Signup.index.field_confirmpassword'] = 'Confirmați parola';
$lang['Signup.index.field_newpassword'] = 'Parola';
$lang['Signup.index.field_password'] = 'Parola';
$lang['Signup.index.field_username'] = 'Nume utilizator';
$lang['Signup.index.field_action_signup'] = 'Creați un cont';
$lang['Signup.index.field_action_login'] = 'Autentificare';
$lang['Signup.index.field_action_continue'] = 'Continuați ca %1$s %2$s';
$lang['Signup.index.field_username_type_username'] = 'Specificați un nume de utilizator';
$lang['Signup.index.field_username_type_email'] = 'Utilizați e-mailul ca nume de utilizator';
$lang['Signup.index.field_email'] = 'Email';
$lang['Signup.index.field_fax'] = 'Fax';
$lang['Signup.index.field_phone'] = 'Telefon';
$lang['Signup.index.field_title'] = 'Titlu';
$lang['Signup.index.field_country'] = 'Țara';
$lang['Signup.index.field_zip'] = 'Cod poștal';
$lang['Signup.index.field_state'] = 'Stat/Provincie';
$lang['Signup.index.field_city'] = 'Orașul';
$lang['Signup.index.field_address2'] = 'Adresa 2';
$lang['Signup.index.field_address1'] = 'Adresa 1';
$lang['Signup.index.field_company'] = 'Companie/Org.';
$lang['Signup.index.field_lastname'] = 'Numele de familie';
$lang['Signup.index.field_firstname'] = 'Primul nume';
$lang['Signup.index.field_taxid'] = 'Cod fiscal/VATIN';
$lang['Signup.!notice.email_verification'] = 'A fost trimis un mesaj pentru a verifica adresa dvs. de e-mail. Vă rugăm să finalizați verificarea cât mai curând posibil.';
$lang['Signup.!notice.force_email_usernames'] = 'Numele dvs. de utilizator va fi același cu adresa dvs. de e-mail.';
$lang['Signup.!error.not_client_owner'] = 'Trebuie să vă conectați ca proprietar al clientului pentru a continua.';
$lang['Signup.!error.captcha.invalid'] = 'Captcha introdus a fost invalid. Vă rugăm să încercați din nou.';
$lang['Signup.otp.field_submit'] = 'Conectați-vă';
$lang['Signup.otp.field_otp'] = 'Parolă unică';
$lang['Signup.otp.login_heading'] = 'Conectați-vă';
$lang['Signup.otp.description'] = 'Vă rugăm să introduceți parola unică.';
$lang['Signup.otp.page_title'] = 'Conectați-vă';
$lang['Signup.index.field_agree_tos'] = 'Am citit și sunt de acord cu <a href="%1$s" target="_blank">Termenii și condițiile</a>';
$lang['Signup.!error.invalid_agree_tos'] = 'Trebuie să confirmați că sunteți de acord cu termenii și condițiile.';
